==> xmapcore_1.2.8.tar.gz: xmapcore/man/xmapcore.utr.Rd <==
\name{xmapcore.utr}
\alias{transcript.to.utr.range}
\alias{transcript.to.coding.range}
\alias{utr.probesets}
\alias{coding.probesets}
\title{
  xmapcore coding functions
}
\description{
  Functions to deal with coding regions and UTRs
}
\usage{
  transcript.to.utr.range( ids, end=c( "both", "5", "3" ) )
  transcript.to.coding.range( ids, end=c( "both", "5", "3" ) )
  utr.probesets( probesets, transcripts, end=c( "both", "5", "3" ) )
  coding.probesets( probesets, transcripts, end=c( "both", "5", "3" ) )
}
\arguments{
  \item{ids}{ A vector of Transcript Names, or a RangedData object of Transcripts returned from another xmapcore call. }
  \item{probesets}{ An optional vector of Probeset Names, or a RangedData object of Probesets returned from another xmapcore call. }
  \item{transcripts}{ An optional vector of Transcript Names, or a RangedData object of Transcripts returned from another xmapcore call. }
  \item{end}{ Which end (\code{"both"}, \code{"3"} or \code{"5"}) of the Transcript(s) you are interested in (defaults to \code{both}). }
}
\details{
  The first two functions given here, \code{transcript.to.utr.range} and \code{transcript.to.coding.range} return the transcripts
  of interest, with their ranges adjusted depending on the UTR of each.

  With \code{transcript.to.utr.range}, a RangedData object is returned with the name of the transcript, the end in question, and
  the genomic location of that UTR.  If \code{both} is passed as the \code{end} parameter, then each transcript will generate up to
  two rows in the returned object.  It may return less than two rows if the \code{end} parameter is used, or if there is no UTR for the
  end specified. (A Transcript with no UTR will return zero results)

  The \code{transcript.to.coding.range} function returns the same as calling \code{transcript.details}, but with the start and end locations
  modified by the range of the UTR.  If \code{end} is passed, then only the UTR at this end will be taken into consideration and used to modify
  the returned location.

  \code{utr.probesets} and \code{coding.probesets} are functions to find or filter probesets which have probes targeting the type of region
  specified by the function name.

  A call to \code{utr.probesets} with a list of Probesets will return those probesets that have at least one probe hitting the UTR of any transcript.

  A call to \code{utr.probesets} with a list of Probesets and a list of Transcripts will return those probesets the have at least one probe
  hitting the UTR of any of the specified Transcripts.

  A call to \code{utr.probesets} with only the \code{probesets} parameter omitted, will return all probesets which have at least one probe in the UTR
  region of the specified Transcripts.

  You cannot omit both the Probesets and Transcripts parameters simultaneously.

  The \code{coding.probesets} method does the inverse of the \code{utr.probesets} function: it returns probesets having at least one probe
  in the coding region of a Transcipt (or the specified Transcripts).

  Note that the UTR of a Transcript includes the intronic UTR regions, and the coding region of a Transcript includes the
  intronic coding regions.

  This means that \code{utr.probesets} and \code{coding.probesets} can sometimes return \code{intronic} and/or \code{intergenic} probesets.
  These can be removed with a call to the appropriate filter function (see examples).
  
  All \code{unreliable} probesets are automatically removed by these functions before mapping.
}
\seealso{
  \code{\link{xmapcore.to}}\cr
  \code{\link{xmapcore.details}}\cr
  \code{\link{xmapcore.all}}\cr
  \code{\link{xmapcore.range}}\cr
  \code{\link{xmapcore.filters}}\cr
}
\author{
  Tim Yates
}
\examples{
  if(interactive()) {
    # Only return exonic probesets hitting the UTRs of ENST00000414566
    exonic( utr.probesets( NULL, "ENST00000414566" ) )
  }
}

==> xmapcore_1.12.0.tar.gz: xmapcore/man/xmapcore.utr.Rd <==
\name{xmapcore.utr}
\alias{transcript.to.utr.range}
\alias{transcript.to.coding.range}
\alias{utr.probesets}
\alias{coding.probesets}
\title{
  xmapcore coding functions
}
\description{
  Functions to deal with coding regions and UTRs
}
\usage{
  transcript.to.utr.range( ids, end=c( "both", "5", "3" ), as.data.frame=FALSE )
  transcript.to.coding.range( ids, end=c( "both", "5", "3" ), as.data.frame=FALSE )
  utr.probesets( probesets, transcripts, end=c( "both", "5", "3" ) )
  coding.probesets( probesets, transcripts, end=c( "both", "5", "3" ) )
}
\arguments{
  \item{ids}{ A vector of Transcript Names, or a RangedData object of Transcripts returned from another xmapcore call. }
  \item{as.data.frame}{ If \code{FALSE}, data will be converted to a \code{RangedData} object if possible, otherwise a \code{data.frame} }
  \item{probesets}{ An optional vector of Probeset Names, or a RangedData object of Probesets returned from another xmapcore call. }
  \item{transcripts}{ An optional vector of Transcript Names, or a RangedData object of Transcripts returned from another xmapcore call. }
  \item{end}{ Which end (\code{"both"}, \code{"3"} or \code{"5"}) of the Transcript(s) you are interested in (defaults to \code{both}). }
}
\details{
  The first two functions given here, \code{transcript.to.utr.range} and \code{transcript.to.coding.range} return the transcripts
  of interest, with their ranges adjusted depending on the UTR of each.

  With \code{transcript.to.utr.range}, a RangedData object is returned with the name of the transcript, the end in question, and
  the genomic location of that UTR.  If \code{both} is passed as the \code{end} parameter, then each transcript will generate up to
  two rows in the returned object.  It may return less than two rows if the \code{end} parameter is used, or if there is no UTR for the
  end specified. (A Transcript with no UTR will return zero results)

  The \code{transcript.to.coding.range} function returns the same as calling \code{transcript.details}, but with the start and end locations
  modified by the range of the UTR.  If \code{end} is passed, then only the UTR at this end will be taken into consideration and used to modify
  the returned location.

  \code{utr.probesets} and \code{coding.probesets} are functions to find or filter probesets which have probes targeting the type of region
  specified by the function name.

  A call to \code{utr.probesets} with a list of Probesets will return those probesets that have at least one probe hitting the UTR of any transcript.

  A call to \code{utr.probesets} with a list of Probesets and a list of Transcripts will return those probesets the have at least one probe
  hitting the UTR of any of the specified Transcripts.

  A call to \code{utr.probesets} with only the \code{probesets} parameter omitted, will return all probesets which have at least one probe in the UTR
  region of the specified Transcripts.

  You cannot omit both the Probesets and Transcripts parameters simultaneously.

  The \code{coding.probesets} method does the inverse of the \code{utr.probesets} function: it returns probesets having at least one probe
  in the coding region of a Transcipt (or the specified Transcripts).

  Note that the UTR of a Transcript includes the intronic UTR regions, and the coding region of a Transcript includes the
  intronic coding regions.

  This means that \code{utr.probesets} and \code{coding.probesets} can sometimes return \code{intronic} and/or \code{intergenic} probesets.
  These can be removed with a call to the appropriate filter function (see examples).
  
  All \code{unreliable} probesets are automatically removed by these functions before mapping.
}
\seealso{
  \code{\link{xmapcore.to}}\cr
  \code{\link{xmapcore.details}}\cr
  \code{\link{xmapcore.all}}\cr
  \code{\link{xmapcore.range}}\cr
  \code{\link{xmapcore.filters}}\cr
}
\author{
  Tim Yates
}
\examples{
  if(interactive()) {
    # Only return exonic probesets hitting the UTRs of ENST00000414566
    exonic( utr.probesets( NULL, "ENST00000414566" ) )
  }
}
